@@ -51,12 +51,7 @@ def decompose_sales(sales_data):
     year_trend = forecast_reduced.groupby("woy").mean()
     year_trend = year_trend["yearly"] + 1
 
-    # ensure 53 weeks are calculated by wrapping week values to end of the year
-    if len(year_trend) < 53:
-        delta = 53 - len(year_trend)
-        yearly_seasonality = pd.concat(
-            [year_trend, year_trend[:delta]], ignore_index=True
-        )
+    yearly_seasonality = ensure_53_weeks(year_trend)
 
     if len(weekly_seasonality) == 7 and len(yearly_seasonality) == 53:
         return yearly_seasonality, weekly_seasonality
@@ -64,6 +59,18 @@ def decompose_sales(sales_data):
     return pd.Series([1] * 53), pd.Series([1] * 7)
 
 
+def ensure_53_weeks(initial: pd.DataFrame) -> pd.DataFrame:
+    """
+    takes a shorter dataframe and ensures at least 53 rows by wrapping the first rows onto the end
+    """
+    extra_weeks_needed = 53 - len(initial)
+    if extra_weeks_needed > 0:
+        ret = pd.concat([initial, initial[:extra_weeks_needed]], ignore_index=True)
+    else:
+        ret = initial.copy()
+    return ret
+
+
 def decompose_tank(tank_history):
 
     if tank_history is None or len(tank_history) < 48:
