@@ -7,12 +7,21 @@ import pandas as pd
 
 def format_tank(dict_input, freq: str = "30min"):
 
-    if dict_input == [] or dict_input is None:
+    if dict_input is None:
         return None
 
-    dict_input = sorted(dict_input, key=lambda x: x["read_time"])
-    dict_input = [d for d in dict_input if d["volume"]]
-    df = pd.DataFrame(dict_input)
+    validated_input = []
+
+    for i in range(len(dict_input)):
+        if "read_time" in dict_input[i] and "volume" in dict_input[i]:
+            validated_input.append(dict_input[i])
+
+    if validated_input == []:
+        return None
+
+    validated_input = sorted(validated_input, key=lambda x: x["read_time"])
+    validated_input = [d for d in validated_input if d["volume"]]
+    df = pd.DataFrame(validated_input)
     df.read_time = pd.to_datetime(df.read_time)
     df["y"] = df.volume.diff() * -1
     df = df[["read_time", "y"]].rename(columns={"read_time": "ds"})
@@ -130,3 +139,54 @@ def validate_tank(tank_data, sales_data):
     val_df.rename(columns={"ds_x": "ds"}, inplace=True)
 
     return val_df[["ds", "y"]]
+
+
+if __name__ == "__main__":
+    raw_readings = [
+        {
+            "id": "5f8de916228d65344402f0a7",
+            "store_number": "110",
+            "tank_id": "1",
+            # "run_time": "2020-10-19T19:29:17",
+            # "read_time": "2020-10-19T19:29:23",
+            "volume": 13547.508587862303,
+            "temperature": 48.1715720177702,
+        },
+        {
+            "id": "5f8de914228d65344402f083",
+            "store_number": "110",
+            "tank_id": "1",
+            "run_time": "2 020-10-19T19:29:16",
+            # "read_time": "2020-10-19T19:29:21",
+            # "volume": 13549.028743568035,
+            "temperature": 48.1710855651926,
+        },
+        {
+            "id": "5f8de49c1c6cbdc17a3546f9",
+            "store_number": "110",
+            "tank_id": "1",
+            # "run_time": "2020-10-19T19:10:13",
+            # "read_time": "2020-10-19T19:10:18",
+            "volume": 13621.377813533778,
+            "temperature": 48.0932317562486,
+        },
+        {
+            "id": "5f8de49b1c6cbdc17a3546e5",
+            "store_number": "110",
+            "tank_id": "1",
+            "run_time": "2020-10-19T19:10:13",
+            "read_time": "2020-10-19T19:10:16",
+            # "volume": 13621.377813533778,
+            "temperature": 48.0932317562486,
+        },
+        {
+            "id": "5f8de0011dff1f3a8c927fc1",
+            "store_number": "110",
+            "tank_id": "1",
+            "run_time": "2020-10-19T18:50:35",
+            "read_time": "2020-10-19T18:50:37",
+            # "volume": 13792.582207190737,
+            "temperature": 48.025463112635,
+        },
+    ]
+    format_tank(raw_readings)
